@@ -11,11 +11,6 @@ import distro
 import pytest
 
 
-def _is_firewalld_supported():
-    info = distro.id()
-    return info in ['centos', 'rocky']
-
-
 def _is_apt():
     info = distro.linux_distribution()
     return info[0].startswith('Ubuntu')
@@ -25,10 +20,12 @@ def _is_dnf():
     info = distro.id()
     return info in ['centos', 'rocky']
 
+
 def _is_dnf_mirror():
     info = distro.id()
     return info == 'centos'
 
+
 def test_network_ethernet(host):
     interface = host.interface('dummy2')
     assert interface.exists
@@ -44,7 +41,8 @@ def test_network_ethernet_vlan(host):
     assert host.file('/sys/class/net/dummy2.42/lower_dummy2').exists
     # FIXME(bbezak): remove following IF after ansible-role-interfaces
     # receive support for custom routes in NetworkManager
-    if not host.system_info.release.startswith('9'):
+    if not ('centos' in host.system_info.distribution.lower() or
+            'rocky' in host.system_info.distribution.lower()):
        routes = host.check_output(
            '/sbin/ip route show dev dummy2.42 table kayobe-test-route-table')
        assert '192.168.40.0/24 via 192.168.35.254' in routes
@@ -58,8 +56,6 @@ def test_network_bridge(host):
     interface = host.interface('br0')
     assert interface.exists
     assert '192.168.36.1' in interface.addresses
-    stp_status = host.file('/sys/class/net/br0/bridge/stp_state').content_string.strip()
-    assert '0' == stp_status
     ports = ['dummy3', 'dummy4']
     sys_ports = host.check_output('ls -1 /sys/class/net/br0/brif')
     assert sys_ports == "\n".join(ports)
@@ -104,9 +100,6 @@ def test_network_bridge_no_ip(host):
     interface = host.interface('br1')
     assert interface.exists
     assert not '192.168.40.1' in interface.addresses
-    if not host.system_info.release.startswith('8'):
-       stp_status = host.file('/sys/class/net/br1/bridge/stp_state').content_string.strip()
-       assert '1' == stp_status
 
 
 @pytest.mark.skipif(not _is_apt(),
@@ -192,7 +185,7 @@ def test_ntp_running(host):
 def test_ntp_non_default_time_server(host):
     # Tests that the NTP pool has been changed from pool.ntp.org to
     # time.cloudflare.com
-    if ('centos' in host.system_info.distribution.lower() or 
+    if ('centos' in host.system_info.distribution.lower() or
        'rocky' in host.system_info.distribution.lower()):
         chrony_config = host.file("/etc/chrony.conf")
     else:
@@ -256,16 +249,12 @@ def test_tuned_profile_is_active(host):
     assert "throughput-performance" in tuned_output
 
 
-@pytest.mark.skipif(not _is_firewalld_supported(),
-                    reason="Firewalld only supported on CentOS and Rocky")
 def test_firewalld_running(host):
     assert host.package("firewalld").is_installed
     assert host.service("firewalld.service").is_enabled
     assert host.service("firewalld.service").is_running
 
 
-@pytest.mark.skipif(not _is_firewalld_supported(),
-                    reason="Firewalld only supported on CentOS and Rocky")
 def test_firewalld_zones(host):
     # Verify that interfaces are on correct zones.
     expected_zones = {
@@ -287,8 +276,6 @@ def test_firewalld_zones(host):
             assert zone == expected_zone
 
 
-@pytest.mark.skipif(not _is_firewalld_supported(),
-                    reason="Firewalld only supported on CentOS and Rocky")
 def test_firewalld_rules(host):
     # Verify that expected rules are present.
     expected_info = {
@@ -326,3 +313,11 @@ def test_firewalld_rules(host):
         for expected_line in expected_lines:
             assert expected_line in info
             assert expected_line in perm_info
+
+
+def test_swap(host):
+    swapon = host.check_output("swapon -s")
+    swapon = swapon.splitlines()
+    assert len(swapon) > 1
+    swap_devs = [swap.split()[0] for swap in swapon[1:]]
+    assert "/swapfile" in swap_devs
